@@ -4,11 +4,11 @@ import time
 import numpy as np
 
 __author__ = "Lei Hu <hulei@pmo.ac.cn>"
-__version__ = "v1.0"
+__version__ = "v1.1"
 
 class ElementalSFFTSubtract_Pycuda:
     @staticmethod
-    def ESSP(PixA_I, PixA_J, SFFTConfig, SFFTSolution=None, Subtract=False, CUDA_DEVICE='0'):
+    def ESSP(PixA_I, PixA_J, SFFTConfig, SFFTSolution=None, Subtract=False, CUDA_DEVICE_4SUBTRACT='0'):
 
         import warnings
         import pycuda.autoinit
@@ -19,7 +19,7 @@ class ElementalSFFTSubtract_Pycuda:
             import skcuda.fft as cu_fft
             import skcuda.linalg as sklinalg
             import skcuda.cusolver as sksolver
-        os.environ["CUDA_DEVICE"] = CUDA_DEVICE
+        os.environ["CUDA_DEVICE"] = CUDA_DEVICE_4SUBTRACT
 
         def LSSolver(LHMAT_GPU, RHb_GPU):
 
@@ -521,11 +521,11 @@ class ElementalSFFTSubtract_Pycuda:
 
 class ElementalSFFTSubtract_Cupy:
     @staticmethod
-    def ESSC(PixA_I, PixA_J, SFFTConfig, SFFTSolution=None, Subtract=False, CUDA_DEVICE='0'):
+    def ESSC(PixA_I, PixA_J, SFFTConfig, SFFTSolution=None, Subtract=False, CUDA_DEVICE_4SUBTRACT='0'):
 
         import cupy as cp
         import cupyx.scipy.linalg as cpx_linalg
-        os.environ["CUDA_DEVICE"] = CUDA_DEVICE
+        os.environ["CUDA_DEVICE"] = CUDA_DEVICE_4SUBTRACT
 
         def LSSolver(LHMAT_GPU, RHb_GPU):
             """
@@ -1000,10 +1000,10 @@ class ElementalSFFTSubtract_Cupy:
 
 class ElementalSFFTSubtract_Numpy:
     @staticmethod
-    def ESSN(PixA_I, PixA_J, SFFTConfig, SFFTSolution=None, Subtract=False, NUM_CPU_THREADS=8):
+    def ESSN(PixA_I, PixA_J, SFFTConfig, SFFTSolution=None, Subtract=False, NUM_CPU_THREADS_4SUBTRACT=8):
 
         import pyfftw
-        pyfftw.config.NUM_THREADS = NUM_CPU_THREADS
+        pyfftw.config.NUM_THREADS = NUM_CPU_THREADS_4SUBTRACT
         pyfftw.interfaces.cache.enable()
         
         ta = time.time()
@@ -1337,22 +1337,27 @@ class ElementalSFFTSubtract_Numpy:
 
 class ElementalSFFTSubtract:
     @staticmethod
-    def ESS(PixA_I, PixA_J, SFFTConfig, SFFTSolution=None, Subtract=False, backend='Pycuda', CUDA_DEVICE='0', NUM_CPU_THREADS=8):
- 
-        if backend == 'Pycuda':
-            Solution, PixA_DIFF = ElementalSFFTSubtract_Pycuda.ESSP(PixA_I=PixA_I, PixA_J=PixA_J, SFFTConfig=SFFTConfig, SFFTSolution=SFFTSolution, Subtract=Subtract, CUDA_DEVICE=CUDA_DEVICE)
-        
-        if backend == 'Cupy':
-            Solution, PixA_DIFF = ElementalSFFTSubtract_Cupy.ESSC(PixA_I=PixA_I, PixA_J=PixA_J, SFFTConfig=SFFTConfig, SFFTSolution=SFFTSolution, Subtract=Subtract, CUDA_DEVICE=CUDA_DEVICE)
+    def ESS(PixA_I, PixA_J, SFFTConfig, SFFTSolution=None, Subtract=False, \
+        BACKEND_4SUBTRACT='Pycuda', CUDA_DEVICE_4SUBTRACT='0', NUM_CPU_THREADS_4SUBTRACT=8):
 
-        if backend == 'Numpy':
-            Solution, PixA_DIFF = ElementalSFFTSubtract_Numpy.ESSN(PixA_I=PixA_I, PixA_J=PixA_J, SFFTConfig=SFFTConfig, SFFTSolution=SFFTSolution, Subtract=Subtract, NUM_CPU_THREADS=NUM_CPU_THREADS)
+        if BACKEND_4SUBTRACT == 'Pycuda':
+            Solution, PixA_DIFF = ElementalSFFTSubtract_Pycuda.ESSP(PixA_I=PixA_I, PixA_J=PixA_J, SFFTConfig=SFFTConfig, \
+                SFFTSolution=SFFTSolution, Subtract=Subtract, CUDA_DEVICE_4SUBTRACT=CUDA_DEVICE_4SUBTRACT)
+        
+        if BACKEND_4SUBTRACT == 'Cupy':
+            Solution, PixA_DIFF = ElementalSFFTSubtract_Cupy.ESSC(PixA_I=PixA_I, PixA_J=PixA_J, SFFTConfig=SFFTConfig, \
+                SFFTSolution=SFFTSolution, Subtract=Subtract, CUDA_DEVICE_4SUBTRACT=CUDA_DEVICE_4SUBTRACT)
+
+        if BACKEND_4SUBTRACT == 'Numpy':
+            Solution, PixA_DIFF = ElementalSFFTSubtract_Numpy.ESSN(PixA_I=PixA_I, PixA_J=PixA_J, SFFTConfig=SFFTConfig, \
+                SFFTSolution=SFFTSolution, Subtract=Subtract, NUM_CPU_THREADS_4SUBTRACT=NUM_CPU_THREADS_4SUBTRACT)
         
         return Solution, PixA_DIFF
 
 class GeneralSFFTSubtract:
     @staticmethod
-    def GSS(PixA_I, PixA_J, PixA_mI, PixA_mJ, SFFTConfig, ContamMask_I=None, backend='Pycuda', CUDA_DEVICE='0', NUM_CPU_THREADS=8):
+    def GSS(PixA_I, PixA_J, PixA_mI, PixA_mJ, SFFTConfig, ContamMask_I=None, \
+        BACKEND_4SUBTRACT='Pycuda', CUDA_DEVICE_4SUBTRACT='0', NUM_CPU_THREADS_4SUBTRACT=8):
 
         """
         # Arguments:
@@ -1364,15 +1369,44 @@ class GeneralSFFTSubtract:
         # f) ContamMask_I: Contaminate-Region in Image I (e.g., Saturation and Bad pixels).
         #               We will calculate the propagated Contaminate-Region on convolved I.
         # 
-        # g) backend: Which backend would you like to perform SFFT on ?
-        # h) CUDA_DEVICE (backend = Pycuda / Cupy): Which GPU device would you want to perform SFFT on ?
-        # i) NUM_CPU_THREADS (backend = Numpy): How many CPU threads would you want to perform SFFT on ?
+        # g) BACKEND_4SUBTRACT: Which backend would you like to perform SFFT subtraction on ?
+        # h) CUDA_DEVICE_4SUBTRACT (BACKEND_4SUBTRACT = Pycuda / Cupy): Which GPU device would you want to perform SFFT subtraction on ?
+        # i) NUM_CPU_THREADS_4SUBTRACT (BACKEND_4SUBTRACT = Numpy): How many CPU threads would you want to perform SFFT subtraction on ?
         #
         # NOTE: The SFFT parameter-solving is performed between mI & mJ, 
         #       then we apply the solution to input Images I & J.
         #
         """
         
+        print(r"""
+                                __    __    __    __
+                               /  \  /  \  /  \  /  \
+                              /    \/    \/    \/    \
+            █████████████████/  /██/  /██/  /██/  /█████████████████████████
+                            /  / \   / \   / \   / \  \____
+                           /  /   \_/   \_/   \_/   \    o \__,
+                          / _/                       \_____/  `
+                          |/
+
+                      █████████  ███████████ ███████████ ███████████        
+                     ███░░░░░███░░███░░░░░░█░░███░░░░░░█░█░░░███░░░█            
+                    ░███    ░░░  ░███   █ ░  ░███   █ ░ ░   ░███  ░ 
+                    ░░█████████  ░███████    ░███████       ░███    
+                     ░░░░░░░░███ ░███░░░█    ░███░░░█       ░███    
+                     ███    ░███ ░███  ░     ░███  ░        ░███    
+                    ░░█████████  █████       █████          █████   
+                     ░░░░░░░░░  ░░░░░       ░░░░░          ░░░░░         
+
+                    Saccadic Fast Fourier Transform (SFFT) algorithm
+                    sfft (1.1) supported by @LeiHu
+
+                    GitHub: https://github.com/thomasvrussell/sfft
+                    Related Paper: https://arxiv.org/abs/2109.09334
+                    
+            ████████████████████████████████████████████████████████████████
+            
+            """)
+        
         # * Size-Check Processes
         tmplst = [PixA_I.shape, PixA_J.shape]
         tmplst += [PixA_mI.shape, PixA_mI.shape]
@@ -1381,13 +1415,13 @@ class GeneralSFFTSubtract:
 
         # * Subtraction Solution derived from input masked image-pair
         Solution = ElementalSFFTSubtract.ESS(PixA_I=PixA_mI, PixA_J=PixA_mJ, \
-            SFFTConfig=SFFTConfig, SFFTSolution=None, Subtract=False, backend=backend, \
-            CUDA_DEVICE=CUDA_DEVICE, NUM_CPU_THREADS=NUM_CPU_THREADS)[0]
+            SFFTConfig=SFFTConfig, SFFTSolution=None, Subtract=False, BACKEND_4SUBTRACT=BACKEND_4SUBTRACT, \
+            CUDA_DEVICE_4SUBTRACT=CUDA_DEVICE_4SUBTRACT, NUM_CPU_THREADS_4SUBTRACT=NUM_CPU_THREADS_4SUBTRACT)[0]
         
         # * Subtraction of the input image-pair (use above solution)
         PixA_DIFF = ElementalSFFTSubtract.ESS(PixA_I=PixA_I, PixA_J=PixA_J, \
-            SFFTConfig=SFFTConfig, SFFTSolution=Solution, Subtract=True, backend=backend, \
-            CUDA_DEVICE=CUDA_DEVICE, NUM_CPU_THREADS=NUM_CPU_THREADS)[1]
+            SFFTConfig=SFFTConfig, SFFTSolution=Solution, Subtract=True, BACKEND_4SUBTRACT=BACKEND_4SUBTRACT, \
+            CUDA_DEVICE_4SUBTRACT=CUDA_DEVICE_4SUBTRACT, NUM_CPU_THREADS_4SUBTRACT=NUM_CPU_THREADS_4SUBTRACT)[1]
 
         # * Identify propagated contamination region through convolving I
         ContamMask_CI = None
@@ -1401,8 +1435,8 @@ class GeneralSFFTSubtract:
 
             # NOTE Convolved_I is inverse DIFF
             _tmpD = ElementalSFFTSubtract.ESS(PixA_I=_tmpI, PixA_J=_tmpJ, \
-                SFFTConfig=SFFTConfig, SFFTSolution=tSolution, Subtract=True, backend=backend, \
-                CUDA_DEVICE=CUDA_DEVICE, NUM_CPU_THREADS=NUM_CPU_THREADS)[1]
+                SFFTConfig=SFFTConfig, SFFTSolution=tSolution, Subtract=True, BACKEND_4SUBTRACT=BACKEND_4SUBTRACT, \
+                CUDA_DEVICE_4SUBTRACT=CUDA_DEVICE_4SUBTRACT, NUM_CPU_THREADS_4SUBTRACT=NUM_CPU_THREADS_4SUBTRACT)[1]
             ContamMask_CI = _tmpD < -0.001     # FIXME Customizable
         
         return Solution, PixA_DIFF, ContamMask_CI
